@@ -384,6 +384,10 @@ class CookBookUi:
 				ct=len(results_2)
 				for num,i in enumerate(results_2):
 					print(std_colorize(i,num,ct))
+					page=Control(func=FormBuilderMkText,ptext="Next?",helpText="next result!",data="boolean")
+					if page in [None,'NaN']:
+						return
+					
 			except Exception as e:
 				print(e)
 
