@@ -294,8 +294,14 @@ def DateTimePkr(DATE=None):
     while True:
         tm=TimePkr()
         if not tm:
-            raise Exception("Time is Missing!")
-            tm=TimePkr()
+            try:
+                x=datetime.now()
+                #tm=TimePkr()
+                tm=_time_(x.hour,x.minute,x.second)
+                break
+            except Exception as e:
+                print(e)
+                raise Exception("Time is Missing!")
         else:
             break
     while True:
@@ -304,7 +310,12 @@ def DateTimePkr(DATE=None):
         else:
             dt=DatePkr()
         if not dt:
-            raise Exception("Date is Missing!")
+            try:
+                dt=datetime.now()
+                break
+            except Exception as e:
+                print(e)
+                raise Exception("Date is Missing!")
         else:
             break
 
