@@ -235,6 +235,11 @@ class Lookup:
 			'cmds':['14.1','sch spec sht','schspecsht','spec sch sht','search specific short','ssps','ssp-'],
 			'exec':lambda self=self:self.searchSpec(short=True),
 			'desc':f'{Fore.light_blue}Search For Product by Entry Data using prompted fields'
+			},
+		uuid1():{
+			'cmds':['14.2','save eid to text','save eid txt'],
+			'exec':lambda self=self:self.saveEID(),
+			'desc':f'{Fore.light_blue}Save An Entry to Text'
 			}
 		}
 		def mehelp(self):
@@ -261,7 +266,32 @@ class Lookup:
 					else:
 						self.cmds[i]['exec']()
 						break
-
+	def saveEID(self):
+		try:
+			EntryTXT=Path('EntryTXT.txt')
+			with Session(ENGINE) as session:
+				eids=Control(func=FormBuilderMkText,ptext=f"EntryId's to save to '{EntryTXT}'?",helpText="EntryId is an Integer, separate them with commas",data="list")
+				if eids is None:
+					return
+				tmp=[]
+				for eid in eids:
+					if eid not in tmp:
+						tmp.append(eid)
+				eids=tmp
+				for num,eid in enumerate(eids):
+					try:
+						eid=int(eid)
+						result=session.query(Entry).filter(Entry.EntryId==eid).first()
+						if result is not None:
+							mode="w"
+							if num > 0:
+								mode="a"
+							with open(EntryTXT,mode) as out:
+								out.write(strip_colors(str(result)))
+					except Exception as ee:
+						print(ee)
+		except Exception as e:
+			print(e)
 	def entryDataExtrasSearchExport(self,txt_export=False):
 		with Session(ENGINE) as session:
 			while True:
