@@ -1674,21 +1674,26 @@ def drug_text():
                         for line in reader:
                             for sub in line:
                                 if sub not in ['',]:
+                                    sub=f"{sub} {Fore.light_green}[{Fore.cyan}{extra_drugs}{Fore.light_green}]{Fore.dark_goldenrod}"
                                     drug_names.append(sub)
                                     
-
-
+            excludes_drn=['',' ',None,'\n','\r\n','\t',]
+            rdr_state=db.detectGetOrSet('list maker lookup order',False,setValue=False,literal=False)
+            if rdr_state:
+                drug_names=list(sorted(set([i for i in drug_names if i not in excludes_drn]),key=str))
+            else:
+                drug_names=list(reversed(sorted(set([i for i in drug_names if i not in excludes_drn]),key=str)))
             htext=[]
             cta=len(drug_names)
             for num,i in enumerate(drug_names):
                 htext.append(std_colorize(i,num,cta))
             htext='\n'.join(htext)
-            print(htext)
-            which=Control(func=FormBuilderMkText,ptext="which index?",helpText=htext,data="integer")
+            
+            which=Control(func=FormBuilderMkText,ptext=f"{htext}\n{Fore.yellow}which index?",helpText=htext,data="integer")
             if which in [None,'NaN']:
                 return
 
-            return drug_names[which]
+            return strip_colors(drug_names[which])
         except Exception as e:
             print(e)
             continue
@@ -2017,6 +2022,7 @@ def SalesFloorLocationString():
     0-2REC -> from rear endcap 0 to rear endcap 2
     0-2FEC,0-2REC -> from front endcap 0 to front endcap 2 && from rear endcap 0 to rear endcap 2
 
+    if No number is provided, but a common NAME is used, use that here for this section of the location.
 {Fore.orange_red_1}Valid 'Bay[s]/AisleDepth':{Fore.grey_85}
     This is How many shelf bays deep from the front of the store
      to the back, where 0 is the first bay from the endcap at the 
@@ -2030,6 +2036,8 @@ def SalesFloorLocationString():
     0-2R -> from bay 0 to bay 2 on the right side of the aisle
     0-2L -> from bay 0 to bay 2 on the left side of the aisle
     0-2R,0-2L -> from bay 0 to bay 2 on the right side of the aisle && from bay 0 to bay 2 on the left side of the aisle.
+
+    if No number is provided, but a common NAME is used, use that here for this section of the location.    
 {Fore.orange_red_1}Valid Shel[f,ves]:{Fore.grey_85}
     this is the height where the product is on the shelf
     shelves are number 0 to their highest from bottom to top
@@ -2038,7 +2046,12 @@ def SalesFloorLocationString():
     0 -> on shelf 0
     0,1 -> on shelf 0 and  1
     0-2 -> from shelf 0 to shelf 2
-{Fore.light_green}Aisle or EndCap{Fore.light_red}/{Fore.light_yellow}Depth or Bay in Aisle{Fore.light_red}/{Fore.light_steel_blue}Shelf or Location Number(s) Where Item Resides [optional]{Style.reset}"""
+
+    if No number is provided, but a common NAME is used, use that here for this section of the location.    
+{Fore.light_green}Aisle or EndCap{Fore.light_red}/{Fore.light_yellow}Depth or Bay in Aisle{Fore.light_red}/{Fore.light_steel_blue}Shelf or Location Number(s) Where Item Resides [optional]{Style.reset}
+{Fore.light_green}A completely Valid Example is Aisle 0|Household Chemicals|Kitchen Care, which is where Dawn Dish Detergent is normally located.
+{Fore.light_red}{os.get_terminal_size().columns*'/'}
+"""
     fb=FormBuilder(data=fields,passThruText=passThruText)
     if fb is None:
         return
@@ -2070,12 +2083,14 @@ def BackroomLocation():
     u or U -> For U-Boat/Size Wheeler
     rc or rC or Rc or RC ->  for RotaCart
     sc or sC or Sc or SC -> Shopping Cart
+    if a name is used, or common identifier is used, use that here in this segment of the location.
 
 {Fore.orange_red_1}Valid ModuleNumberRange:{Fore.grey_85}
     This which of the what's contains said item.
     0 -> on which 0
     0,1 -> on which 0 and which 1
     0-2 -> from which 0 to which 2 on the left side of the aisle
+    if a name is used, or common identifier is used, use that here in this segment of the location.
 {Fore.orange_red_1}Valid caseID:{Fore.grey_85}
     This is the case where the item is stored in which is the which found on the what.
     anything that you want as long as it is unique to the module in which it is stored.
@@ -2085,6 +2100,9 @@ def BackroomLocation():
      dsur - generate a datestring
      urid - generate reciept id with a log
      cruid - checked uuid
+     if a name is used, or common identifier is used, use that here in this segment of the location.
+{Fore.light_red}{os.get_terminal_size().columns*'/'}
+
     '''
     fb=FormBuilder(data=fields,passThruText=passThruText)
     if fb is None:
